@@ -1,7 +1,7 @@
 package Test::RedisDB;
 use strict;
 use warnings;
-our $VERSION = "2.48_01";
+our $VERSION = "2.47";
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -139,18 +139,6 @@ sub redisdb_client {
     return RedisDB->new(host => 'localhost', port => $self->{port}, @_);
 }
 
-=head2 $self->url
-
-return URL for the server
-
-=cut
-
-sub url {
-    my $self = shift;
-
-    return 'redis://' . ($self->{password} ? ":$self->{password}@" : "") . "localhost:$self->{port}";
-}
-
 1;
 
 __END__
